<?php
/*-----------------------------------*
* Proyecto : SAI                    *
* Autor    : Federico A. Ocampo     *
* Desc: Interfaz web de Seleccion   *
*       para Armado de Informes     *
*-----------------------------------*/

//--------------------------------------
require_once 'PostgreClass.php';
require_once "AppConfig.php";
//--------------------------------------


/*****************************************************************************
.::. Clase ObtieneDatos .::.
@Autor:   Federico A. Ocampo
@Email:   federico@mcanet.com.ar
@Empresa: MCAnet
@Descripcion:	Esta clase provee los metodos para obtener, de la base de datos 
				correspondiente, las diferentes tablas. Realiza las consultas 
				necesarias y retorna, por cada consulta, un arreglo con toda la 
				tabla resultado.
*****************************************************************************/
class ObtieneDatosAdmininf
{
    var $AppConfig;  //Configuracion de la aplicacion
    var $ManejaBD;   //Clase que administra la conexion con la base de datos
    var $DB_CONNECT_ERROR = "FALLO AL CONECTAR CON LA BASE DE DATOS";
    var $DB_QUERY_NULL    = "La consulta no obtuvo resultados";


    /**
    * Constructor: inicializa las propiedades de la clase
    * Recibe todos los parametros por referencia
    * @param AppConfig Objeto con la configuracion de la aplicacion
    * @param ManejadorBD clase para gestionar la conexion con la base de datos
    */
    function ObtieneDatosAdmininf(&$AppConfig, &$ManejadorBaseDatos)
    {
      $this->AppConfig =& $AppConfig;
      $this->ManejaBD  =& $ManejadorBaseDatos;
    }
	
	/*---Leos------------------------------------------------------------------------------*/
	/**
	* Obtiene de la base de datos los datos de la tabla CUENTA
	* @return array Retorna un arreglo multidimensional de la forma arreglo[codigo][descrip]
	*/
	function BuscaOrdenImpresion($p_CodInf, $p_Ver, $p_CodImp, $p_CodSuc)
	{
		if($p_CodSuc=='')
				$v_SQL="SELECT * FROM admininf.auxlisinf, admininf.camdesc WHERE lis_cod='" . $p_CodInf. "' AND lis_ver='". $p_Ver ."' AND cde_ordimp=".$p_CodImp." AND cde_ccam=lis_ccampol2 AND cde_ordimp=".$p_CodImp;
		else
				$v_SQL="SELECT * FROM admininf.auxlisinf, admininf.camdesc WHERE lis_cod='" . $p_CodInf. "' AND lis_ver='". $p_Ver ."' AND cde_ordimp=".$p_CodImp." AND cde_ccam=lis_ccampol2 AND cde_ordimp=".$p_CodImp." AND lis_suc = '". $p_CodSuc ."'";
		
		//trigger_error($v_SQL, E_USER_WARNING);
		return $this->obtenerDatos($v_SQL);
	}
	
	function BuscaOrdenImpresionNew($p_CodInf, $p_Ver, $p_CodCam, $p_CodSuc)
	{
		if($p_CodSuc=='')
				$v_SQL="SELECT * FROM admininf.auxlisinf, admininf.camdesc WHERE lis_cod='" . $p_CodInf. "' AND lis_ver='". $p_Ver ."' AND cde_codcam='".$p_CodCam."' AND lis_ccampol2 >= 21000 AND lis_ccampol2 <= 21999 AND cde_ccam=lis_ccampol2 ";
		else
				$v_SQL="SELECT * FROM admininf.auxlisinf, admininf.camdesc WHERE lis_cod='" . $p_CodInf. "' AND lis_ver='". $p_Ver ."' AND cde_codcam='".$p_CodCam."' AND lis_ccampol2 >= 21000 AND lis_ccampol2 <= 21999 AND cde_ccam=lis_ccampol2  AND lis_suc = '". $p_CodSuc ."'";
		
		/*
		SELECT sum(lis_imp[0]/100), sum(lis_imp[1]/100), sum(lis_imp[2]/100), sum(lis_imp[3]/100), sum(lis_imp[4]/100),  sum(lis_imp[5]/100), sum(lis_imp[6]/100), sum(lis_imp[7]/100)
		FROM admininf.auxlisinf, admininf.camdesc 
		WHERE lis_cod='resu4' AND lis_ver='1201' 
		AND cde_ccam=lis_ccampol2 
		AND lis_ccampol2 >= 21000 AND lis_ccampol2 <= 21999
		AND cde_codcam='CT';*/
		
		trigger_error($v_SQL, E_USER_WARNING);
		return $this->obtenerDatos($v_SQL);
	}
	
	/*---Ayudas----------------------------------------------------------------------------*/
	/**
	* Obtiene de la base de datos la lista de modelos de informacion disponibles
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function ModelosDeInformacionDisponibles()
	{
		$v_SQL = 'SELECT  mod_cod, mod_titpri FROM admininf.modinf ORDER BY mod_cod asc';
		return $this->obtenerDatos($v_SQL);
	}

	function ModelosDeInformacionDescripcion($p_CodInf)
	{
		$v_SQL = 'SELECT  mod_titpri FROM admininf.modinf WHERE mod_cod = \'' . $p_CodInf.'\'';
		return $this->obtenerDatos($v_SQL);
	}

	function VersionDescripcion($p_CodInf, $p_CodVer)
	{
		$v_SQL = "SELECT mov_dmov FROM admininf.modinfv WHERE mov_cod = '" . $p_CodInf . "' AND mov_ver = " . $p_CodVer;
		return $this->obtenerDatos($v_SQL);
	}
		
	/**
	* Obtiene de la base de datos la lista de versiones disponibles
	* @return array Retorna un arreglo bidimensional de la forma arreglo[codigo][descrip]
	*/
	function VersionesDisponibles($p_CodInf)
	{
		//El parametro no puede ser vacio
		if(!empty($p_CodInf))
		{
			//'Sanea' la entrada para evitar ataques SQL-Injection
			$v_CodInfSano = $this->sanearTextoSQL($p_CodInf);
			$v_SQL = "SELECT mov_ver, mov_dmov FROM admininf.modinfv WHERE mov_cod = " . $v_CodInfSano . "ORDER BY mov_ver asc";
		}
		else
		{
			//Si es vacio, genera el warning y devuelvo vacio
			if($this->AppConfig->DEBUG["nivel"] >1)
			{
				$war_msg = "Error en parametros: CodInf";
				trigger_error($war_msg, E_USER_WARNING);
			}
		}
		
		return $this->obtenerDatos($v_SQL);
	}
	
  //-------------------------------------INTERFAZ PRIVADA-------------------------------------/
	/**
	* Accede a la BD y obtiene los resultados de la consulta identificando si existen errores
	* de conexion o consulta
	* @param string <var>consulta</var> sentencia SQL a enviar a la base de datos
	* @return array Retorna un arreglo bidimensional de la forma arreglo[empresa][descrip]
	*/
	function obtenerDatos(&$consulta)
	{
		//Retorno de la funcion
		$ret_datos = "";
	
		//Para manejar errores
		$NIVEL_DEBUG = $this->AppConfig->DEBUG["nivel"];
		$this->ManejaBD->procesoCorrecto  = true;
		
		$procesoCorrecto = $this->ManejaBD->conectarBD();
		if($procesoCorrecto)
		{
			
			$procesoCorrecto = $this->ManejaBD->consultarBD($consulta);
			if($procesoCorrecto)
			{
				if($NIVEL_DEBUG>2) {
				trigger_error("Consulta realizada: $consulta", E_USER_NOTICE);
				}
				//Obtiene un arreglo asociativo de toda la tabla resultado
				$ret_datos = $this->ManejaBD->obtenerTotalFilasArray();
			}
			else
			{
				if($NIVEL_DEBUG>2) {
				trigger_error($this->DB_QUERY_NULL."(SQL ERRONEO): ".$consulta." XXX", E_USER_NOTICE);
				}
				$this->ManejaBD->procesoCorrecto  = false;
			}
			
			$this->ManejaBD->liberarConsulta();
			$this->ManejaBD->desconectarBD();
		}
		else
		{
			$this->ManejaBD->procesoCorrecto  = false;
			trigger_error("Error:". $this->DB_CONNECT_ERROR, E_USER_ERROR);
			die("Error: ". $this->DB_CONNECT_ERROR);//Podria retornarse un valor especifico que indique error
		}
		
		return $ret_datos;
	}
	
	/**
	*Filtra las cadenas recibidas, que formaran parte e una consulta SQL, para evitar SQL-Injection
	*@param string <var>Texto</var> Texto a filtrar
	*@return string Texto filtrado con los caracteres criticos escapados/eliminados
	*/
	function sanearTextoSQL($texto)
	{
		$ret_sts = "";
	
		if(!empty($texto))
		{
			//Si esta activado MagicQuotes se eliminan todas las contrabarras que escapan comillas (ej: '\"' )
			if (get_magic_quotes_gpc())
			{
				$texto = stripslashes($texto);
			}
		
			//Si el valor NO es numerico, se le agregan comillas simples y se escapan los caracteres criticos
			if (!is_numeric($texto))
			{
				$ret_sts = "'"; //comilla incial
		
				//Chequea si existe la funcion mysql_real_escape_string (PHP >= 4.3) para filtrar el texto
				if (function_exists("mysql_real_escape_string"))
				{
					$ret_sts .= mysql_real_escape_string($texto);
				}
				else
				{
					//Si no existe se agregan contrabarras para escapar posibles comillas
					$ret_sts .= addslashes($texto); //IMPLEMENTAR UNA FUNCION ALTERNATIVA A LA INEXISTENTE
				}
				
				$ret_sts .= "'"; //comilla final
			}
		}
		
		return $ret_sts;
	}
}
?>